summaryrefslogtreecommitdiffstats
path: root/tdecore/network/kresolver.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/network/kresolver.h')
-rw-r--r--tdecore/network/kresolver.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdecore/network/kresolver.h b/tdecore/network/kresolver.h
index e2e08623b..1b13d676b 100644
--- a/tdecore/network/kresolver.h
+++ b/tdecore/network/kresolver.h
@@ -796,11 +796,11 @@ public:
* Note that the encoding is illegible and, thus, should not be presented
* to the user, except if requested.
*
* @param unicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.
*/
- static TQCString domainToAscii(const TQString& unicodeDomain);
+ static TQCString domainToAscii(const TQString& tqunicodeDomain);
/**
* Does the inverse of @ref domainToAscii and return an Unicode domain
@@ -796,11 +796,11 @@ public:
* to the user, except if requested.
*
- * @param unicodeDomain the domain name to be encoded
+ * @param tqunicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.